@@ -1,5 +1,4 @@
 use utf8;
-# use strict;
 use warnings;
 no warnings 'redefine';
 use vars qw( $m_sAkt $m_nLength $m_nReplyId );
@@ -157,12 +156,11 @@ sub editNews {
     $id = ($id =~ /^(\d+)$/) ? $1 : 0;
     my $th = param('thread');
     $th = ($th =~ /^(\w+)$/) ? $1 : 'news';
-    if (not defined param('submit') or (param('submit') ne translate('preview'))) {
+    if (not defined param('submit') or (param('submit') ne translate('preview'))  and $th) {
 
         my @data = $m_oDatabase->fetch_array(
             "select title,body,date,id,user,attach,format,cat from  `$th`  where `id` = '$id'  and  (`user` = '$m_sUser'  or `right` < '$m_nRight' );"
-          )
-          if (defined $th);
+          );
         my $catlist = readcats($data[7]);
         my $html = $data[6] eq 'html' ? 1 : 0;
         my %parameter = (
@@ -209,7 +207,7 @@ sub replyNews {
     $th = ($th =~ /^(\w+)$/) ? $1 : 'news';
     my $attachment;
     if ($m_nRight <= 2){
-        eval('
+        eval{
         use Authen::Captcha;
         my $captcha = Authen::Captcha->new(
                                            data_folder   => "$m_hrSettings->{cgi}{bin}/config/",
@@ -218,7 +216,7 @@ sub replyNews {
 
         my $md5sum = $captcha->generate_code(3);
         $attachment = qq|<input size="5" type="hidden" name="md5" value="$md5sum"/><div align="center"><img src="$m_hrSettings->{cgi}{serverName}/images/$md5sum.png" border="0"/><br/><br/><input size="5"" name="captcha" value=""/></div>|;
-        ');
+        };
     }
     my %parameter = (
         action => 'addreply',
@@ -255,11 +253,12 @@ sub addReply {
     }
     my $result = 0;
     if ($m_nRight <= 2) {
-        eval('
-        use Authen::Captcha;
-        my $captcha = Authen::Captcha->new(data_folder   => "$m_hrSettings->{cgi}{bin}/config/",
+        eval{
+	  use Authen::Captcha;
+	  my $captcha = Authen::Captcha->new(data_folder   => "$m_hrSettings->{cgi}{bin}/config/",
                                            output_folder => "$m_hrSettings->{cgi}{DocumentRoot}/images");
-        $result = $captcha->check_code(param("captcha"), param("md5"));');
+	  $result = $captcha->check_code(param("captcha"), param("md5"));
+        };
         $result = 1 if $@;    # skip captcha without gd
     }
     else {
@@ -478,8 +477,7 @@ sub preview {
     my $attachment;
 
     if ($m_nRight <=2){
-        eval(
-            q?
+        eval{
 	use Authen::Captcha;
         my $captcha = Authen::Captcha->new(
                                            data_folder   => "$m_hrSettings->{cgi}{bin}/config/",
@@ -488,8 +486,7 @@ sub preview {
         );
         my $md5sum = $captcha->generate_code('3');
         $attachment = qq|<input size="5" type="hidden" name="md5" value="$md5sum"/><div align="center"><img src="$m_hrSettings->{cgi}{serverName}/$m_hrSettings->{cgi}{prefix}/images/$md5sum.png" border="0"/><br/><br/><input size="5"" name="captcha" value=""/></div>|;
-        ?
-            );
+        };
     }
 
     my %parameter = (
