@@ -26,6 +26,49 @@ sub reg {
      );
 }
 
+sub lostPassword {
+    my $email           = param('email');
+    my $t_lostpassText  = translate('register');
+    my $t_lostpass      = translate('sendpassword');
+    print qq(
+      <div class="dbForm">
+      $t_lostpassText<br/>
+      <form onsubmit="submitForm(this,'makePassword','makePassword');return false;" >
+      <label for="email">Email</label>
+      <br/>
+      <input type="text" name="email" value="$email" id="email" size="20" maxlength="200" alt="email" align="left"/><br/>
+      <input type="hidden" name="action" value="makePassword"/>
+      <br/>
+      <input type="submit" name="submit" value="$t_lostpass" size="15" alt="$t_lostpass" align="left"/>
+      </form>
+      </div>
+     );
+}
+
+sub makePassword {
+    my $fr           = 0;
+    my $sUserRegName = param('username');
+    my $email        = param('email');
+    my $tlt          = translate('register');
+
+    my $hr_user = $m_oDatabase->fetch_hashref("select * from users where email = ?", $email);
+    eval{
+      use Mail::Sendmail;
+      my %mail = (
+		  To      => "$email",
+		  From    => $m_hrSettings->{'admin'}{'email'},
+		  subject => translate('lostpass'),
+		  Message => translate('lostpassmessage')
+		    . translate('username')
+		    . ": $hr_user->{user} "
+		    . translate('password')
+		    . ":$hr_user->{pass}"
+		);
+      sendmail(%mail) or print $Mail::Sendmail::error;
+    };
+    print translate('sendpassword');
+}
+
 sub make {
 
     my $fr           = 0;
@@ -49,20 +92,21 @@ sub make {
         }
         &reg() if ($fr);
         last SWITCH if ($fr);
-
-        use Mail::Sendmail;
         my $pass = int(rand(1000) + 1) x 3;
-        my %mail = (
-                    To      => "$email",
-                    From    => $m_hrSettings->{'admin'}{'email'},
-                    subject => translate('mailsubject'),
-                    Message => translate('regmessage')
-                      . translate('username')
-                      . ": $sUserRegName "
-                      . translate('password')
-                      . ":$pass"
-                   );
-        sendmail(%mail) or print $Mail::Sendmail::error;
+        eval{
+	  use Mail::Sendmail;
+	  my %mail = (
+		      To      => "$email",
+		      From    => $m_hrSettings->{'admin'}{'email'},
+		      subject => translate('mailsubject'),
+		      Message => translate('regmessage')
+			. translate('username')
+			. ": $sUserRegName "
+			. translate('password')
+			. ":$pass"
+		    );
+	  sendmail(%mail) or print $Mail::Sendmail::error;
+        };
         $m_oDatabase->addUser($sUserRegName, $pass, $email);
         my $trlogin = translate('next');
         my $authen  = '';
