@@ -1,59 +1,59 @@
 $VAR1 = {
-          'htmlright' => '2',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'saveTranslate' => '0',
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
           'cgi' => {
-                     'expires' => '+1y',
-                     'cookiePath' => '/',
-                     'DocumentRoot' => '/var/www/htdocs/',
-                     'serverName' => 'http://localhost',
                      'style' => 'mysql',
+                     'expires' => '+1y',
+                     'serverName' => 'http://localhost',
+                     'DocumentRoot' => '/var/www/htdocs/',
                      'bin' => '/var/www/cgi-bin',
+                     'cookiePath' => '/',
                      'title' => 'MySQL::Admin'
                    },
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'news' => {
-                      'messages' => '5',
-                      'captcha' => 3,
-                      'right' => 5
-                    },
-          'tree' => {
-                      'links' => '/var/www/cgi-bin/config/links.pl',
-                      'navigation' => '/var/www/cgi-bin/config/tree.pl'
-                    },
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'files' => {
+                       'group' => 'lze',
+                       'owner' => 'lze',
+                       'chmod' => '0755'
+                     },
+          'size' => '16',
           'admin' => {
                        'password' => 'testpass'
                      },
-          'version' => '1.05',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'version' => '1.06',
+          'floodtime' => 10,
           'uploads' => {
                          'maxlength' => '2100000000000000',
                          'right' => 2,
                          'chmod' => 438,
-                         'path' => '/var/www/htdocs//download',
-                         'enabled' => 1
+                         'enabled' => 1,
+                         'path' => '/var/www/htdocs//download'
                        },
-          'defaultAction' => 'ShowDatabases',
-          'floodtime' => 10,
+          'language' => 'en',
           'database' => {
-                          'CurrentDb' => 'MySQLAdmin',
-                          'password' => '',
-                          'user' => 'root',
-                          'CurrentHost' => 'localhost',
-                          'name' => 'MySQLAdmin',
                           'host' => 'localhost',
                           'CurrentPass' => '',
-                          'CurrentUser' => 'root'
+                          'CurrentUser' => 'root',
+                          'CurrentDb' => 'MySQLAdmin',
+                          'name' => 'MySQLAdmin',
+                          'CurrentHost' => 'localhost',
+                          'password' => '',
+                          'user' => 'root'
                         },
-          'files' => {
-                       'group' => 'lze',
-                       'chmod' => '0755',
-                       'owner' => 'lze'
-                     },
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'language' => 'en',
-          'size' => '16',
-          'mod' => 'n'
+          'news' => {
+                      'messages' => '5',
+                      'right' => 5,
+                      'captcha' => 3
+                    },
+          'defaultAction' => 'ShowDatabases',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'saveTranslate' => '0',
+          'mod' => 'n',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'tree' => {
+                      'links' => '/var/www/cgi-bin/config/links.pl',
+                      'navigation' => '/var/www/cgi-bin/config/tree.pl'
+                    },
+          'htmlright' => '2'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
