@@ -22,6 +22,7 @@ use vars qw(
   $template
   $atemp
   $attach
+  $button
   );
 $style = 'mysql';
 require Exporter;
@@ -29,7 +30,7 @@ require Exporter;
 @HTML::Editor::EXPORT_OK   = qw(initEditor show JsEnabled );
 %HTML::Editor::EXPORT_TAGS = ('all' => [qw(initEditor show JsEnabled)]);
 
-$HTML::Editor::VERSION = '1.05';
+$HTML::Editor::VERSION = '1.06';
 
 $DefaultClass = 'HTML::Editor' unless defined $HTML::Editor::DefaultClass;
 
@@ -37,6 +38,7 @@ $defaultconfig = '%CONFIG%';
 
 our $m_bJsEnabled = 1;
 $right = 0;
+
 =head1 NAME
 
 HTML::Editor - BBCODE and HTML Editor
@@ -73,7 +75,7 @@ sub new {
 
                 class    => "min",
 
-                attach   => '1.05',
+                attach   => '1.01',
 
                 path   => "/srv/www/cgi-bin/templates",#default : '/srv/www/cgi-bin/templates'
 
@@ -173,7 +175,7 @@ sub show {
 
 }
 
-=head2 buttons
+=head1
 
 return the browser buttons
 
@@ -181,6 +183,7 @@ return the browser buttons
 
 sub buttons {
     $style = $_[0] ? shift : $style;
+    $button  = $_[0] ? shift : 1;
     my $buttons = qq|
      <table class="batch">
      <tr>
@@ -210,7 +213,7 @@ sub buttons {
      <a style ="cursor:pointer;" onclick="email();" class="editorButtons" title="email">&#xea84;</a>
      </td>|;
 
-    if ($right >= 2) {
+    if ($right >= 2 && $button) {
         $buttons .=
             '<td class="'
           . ($html ? 'htmlButtonChecked' : 'htmlButton')
@@ -260,7 +263,7 @@ L<CGI> L<HTML::Editor::BBCODE> L<MySQL::Admin::GUI>
 
 =head1 LICENSE
 
-Copyright (C) 2005 - 2015 by Hr. Dirk Lindner
+Copyright (C) 2005 - 201 by Hr. Dirk Lindner
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public License
